# Abdullah-Encrypt
## How to install?
 pip install Abdullah-Encrypt
## How to use
 How to use:
         Encode function is used for encryption
          Example:
            import Abdullah_Encrypt
            data = "print('Hi')"
            x = Up.Encode(data)
            print(x)
         The decode function is used for decoding
          Example:
            data = "ごえぐコお('ちぐ')"
            Up.decode(data)
            
